@@ -4,7 +4,6 @@ from python_framework.api.src.enumeration.SchedulerType import SchedulerType
 from python_framework.api.src.service.flask import FlaskManager
 
 
-
 @Function
 def Scheduler() :
     def Wrapper(OuterClass, *args, **kwargs):
@@ -41,7 +40,7 @@ def SchedulerMethod(*methodArgs, requestClass=None, **methodKwargs) :
         def innerResourceInstanceMethod(*args, **kwargs) :
             if self.enabled:
                 resourceInstanceName = methodClassName[:-len(FlaskManager.KW_SCHEDULER_RESOURCE)]
-                log.debug(resourceInstanceMethod, f'Running with args={methodArgs} and kwargs={methodKwargs}')
+                log.debug(resourceInstanceMethod, f'{shedulerId} scheduler started with args={methodArgs} and kwargs={methodKwargs}')
                 resourceInstanceName = f'{resourceInstanceName[0].lower()}{resourceInstanceName[1:]}'
                 args = FlaskManager.getArgumentInFrontOfArgs(args, ReflectionHelper.getAttributeOrMethod(apiInstance.resource.scheduler, resourceInstanceName))
                 resourceInstance = args[0]
@@ -50,11 +49,11 @@ def SchedulerMethod(*methodArgs, requestClass=None, **methodKwargs) :
                     FlaskManager.validateArgs(args,requestClass,innerResourceInstanceMethod)
                     methodReturn = resourceInstanceMethod(*args,**kwargs)
                 except Exception as exception :
+                    log.warning(innerResourceInstanceMethod, f'Not possible to run {shedulerId} properly', exception=exception, muteStackTrace=True)
                     FlaskManager.raiseGlobalException(exception, resourceInstance, resourceInstanceMethod)
-                    log.log(innerResourceInstanceMethod, f'Not possible to run {shedulerId} properly', exception=exception)
-                log.debug(resourceInstanceMethod, f'Completed')
+                log.debug(resourceInstanceMethod, f'{shedulerId} scheduler finished')
                 return methodReturn
-            log.debug(resourceInstanceMethod, f'Not running. Scheadulers are disabled')
+            log.warning(resourceInstanceMethod, f'{shedulerId} scheduler didn{c.SINGLE_QUOTE}t started. Schedulers are disabled')
         ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
         return innerResourceInstanceMethod
     return innerMethodWrapper
